| future_imap | R Documentation |
These functions work the same as purrr::imap() functions,
but allow you to map in parallel.
future_imap(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_imap_chr(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_imap_dbl(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_imap_int(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_imap_lgl(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_imap_vec(
.x,
.f,
...,
.ptype = NULL,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_imap_dfr(
.x,
.f,
...,
.id = NULL,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_imap_dfc(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_iwalk(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
.x |
A list or atomic vector. |
.f |
A function, specified in one of the following ways:
|
... |
Additional arguments passed on to the mapped function. We now generally recommend against using # Instead of x |> future_map(f, 1, 2, collapse = ",") # do: x |> future_map(\(x) f(x, 1, 2, collapse = ",")) This makes it easier to understand which arguments belong to which function and will tend to yield better error messages. |
.options |
The |
.env_globals |
The environment to look for globals required by |
.progress |
A single logical. Should a progress bar be displayed? Only works with multisession, multicore, and multiprocess futures. Note that if a multicore/multisession future falls back to sequential, then a progress bar will not be displayed. Warning: The |
.ptype |
If |
.id |
Either a string or Only applies to |
A vector the same length as .x.
plan(multisession, workers = 2)
future_imap_chr(sample(10), ~ paste0(.y, ": ", .x))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.