View source: R/future-modify.R
| future_modify | R Documentation |
These functions work the same as purrr::modify() functions, but
allow you to modify in parallel.
future_modify(
.x,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_modify_at(
.x,
.at,
.f,
...,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
future_modify_if(
.x,
.p,
.f,
...,
.else = NULL,
.options = furrr_options(),
.env_globals = parent.frame(),
.progress = FALSE
)
.x |
A vector. |
.f |
A function specified in the same way as the corresponding map function. |
... |
Additional arguments passed on to the mapped function. We now generally recommend against using # Instead of x |> future_map(f, 1, 2, collapse = ",") # do: x |> future_map(\(x) f(x, 1, 2, collapse = ",")) This makes it easier to understand which arguments belong to which function and will tend to yield better error messages. |
.options |
The |
.env_globals |
The environment to look for globals required by |
.progress |
A single logical. Should a progress bar be displayed? Only works with multisession, multicore, and multiprocess futures. Note that if a multicore/multisession future falls back to sequential, then a progress bar will not be displayed. Warning: The |
.at |
A logical, integer, or character vector giving the elements to select. Alternatively, a function that takes a vector of names, and returns a logical, integer, or character vector of elements to select.
|
.p |
A single predicate function, a formula describing such a
predicate function, or a logical vector of the same length as |
.else |
A function applied to elements of |
From purrr:
Since the transformation can alter the structure of the input;
it's your responsibility to ensure that the transformation produces a valid
output. For example, if you're modifying a data frame, .f must preserve the
length of the input.
An object the same class as .x
plan(multisession, workers = 2)
# Convert each col to character, in parallel
future_modify(mtcars, as.character)
iris |>
future_modify_if(is.factor, as.character) |>
str()
mtcars |>
future_modify_at(c(1, 4, 5), as.character) |>
str()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.